%global includetests 0
# 0=no, 1=yes
%global cryptlibdir %{_libdir}/%{name}

Name:       cryptlib
Version:    3.4.8  
Release:    2
Summary:    Security library and toolkit for encryption and authentication services    

Group:      System Environment/Libraries         
License:    Sleepycat and OpenSSL     
URL:        https://www.cs.auckland.ac.nz/~pgut001/cryptlib      
Source0:    https://senderek.ie/cryptlib/source/cryptlib348.zip      
Source3:    https://senderek.ie/cryptlib/source/manual.pdf
Source4:    cryptlib-perlfiles.tar.gz
Source5:    https://senderek.ie/cryptlib/source/cryptlib-tests.tar.gz
Source6:    https://senderek.ie/fedora/cryptlib-tools.tar.gz

# soname is now libcl.so.3.4

BuildRequires: gcc 
##BuildRequires: libbsd-devel   
BuildRequires: gnupg2
BuildRequires: coreutils
BuildRequires: python3 >= 3.5 
BuildRequires: python3-devel >= 3.5
BuildRequires: java-devel
BuildRequires: perl-interpreter
BuildRequires: perl-devel
BuildRequires: perl-generators
BuildRequires: perl-Data-Dumper
BuildRequires: perl-ExtUtils-MakeMaker

%description
Cryptlib is a powerful security toolkit that allows even inexperienced crypto
programmers to easily add encryption and authentication services to their
software. The high-level interface provides anyone with the ability to add
strong security capabilities to an application in as little as half an hour,
without needing to know any of the low-level details that make the encryption
or authentication work.  Because of this, cryptlib dramatically reduces the
cost involved in adding security to new or existing applications.

At the highest level, cryptlib provides implementations of complete security
services such as S/MIME and PGP/OpenPGP secure enveloping, SSL/TLS and
SSH secure sessions, CA services such as CMP, SCEP, RTCS, and OCSP, and other
security operations such as secure time-stamping. Since cryptlib uses
industry-standard X.509, S/MIME, PGP/OpenPGP, and SSH/SSL/TLS data formats,
the resulting encrypted or signed data can be easily transported to other
systems and processed there, and cryptlib itself runs on virtually any
operating system - cryptlib doesn't tie you to a single system.
This allows email, files and EDI transactions to be authenticated with
digital signatures and encrypted in an industry-standard format.



%prep

rm -rf %{name}-%{version}
mkdir %{name}-%{version}
cd %{name}-%{version}
/usr/bin/unzip -a %{SOURCE0}

# CHANGES TO THE ORIGINAL SOURCE CODE

# enable JAVA in config
sed -i 's/\/\* #define USE_JAVA \*\// #define USE_JAVA /' misc/config.h

# remove pre-build jar file
rm %{_builddir}/%{name}-%{version}/bindings/cryptlib.jar
# adapt perl files in bindings
cd %{_builddir}/%{name}-%{version}/bindings
/usr/bin/tar xpzf %{SOURCE4}


%build
cd %{name}-%{version}

# build java bindings
chmod +x tools/mkhdr.sh
tools/mkhdr.sh
cp /etc/alternatives/java_sdk/include/jni.h .
cp /etc/alternatives/java_sdk/include/linux/jni_md.h .

# rename cryptlib symbols that may collide with openssl symbols
chmod +x tools/rename.sh
tools/rename.sh

make clean
make shared %{?_smp_mflags}
make stestlib %{?_smp_mflags}

# build python modules
ln -s libcl.so.3.4.8 libcl.so
cd bindings
python3 setup.py build

# build javadoc
mkdir javadoc
cd javadoc
jar -xf ../cryptlib.jar
javadoc cryptlib


%install
mkdir -p %{buildroot}%{_libdir}
mkdir -p %{buildroot}%{_datadir}/licenses/%{name}
mkdir -p %{buildroot}%{_docdir}/%{name}
cp %{_builddir}/%{name}-%{version}/libcl.so.3.4.8 %{buildroot}%{_libdir}
cd %{buildroot}%{_libdir}
ln -s libcl.so.3.4.8 libcl.so.3
ln -s libcl.so.3 libcl.so

# install header files
mkdir -p %{buildroot}/%{_includedir}/%{name}
cp %{_builddir}/%{name}-%{version}/crypt.h %{buildroot}%{_includedir}/%{name}
cp %{_builddir}/%{name}-%{version}/cryptkrn.h %{buildroot}%{_includedir}/%{name}
cp %{_builddir}/%{name}-%{version}/cryptlib.h %{buildroot}%{_includedir}/%{name}

# add Java bindings
mkdir -p %{buildroot}/%{cryptlibdir}/java
mkdir -p %{buildroot}/%{_jnidir}
cp %{_builddir}/%{name}-%{version}/bindings/cryptlib.jar %{buildroot}%{_jnidir}

# install docs
cp %{_builddir}/%{name}-%{version}/COPYING %{buildroot}%{_datadir}/licenses/%{name}
cp %{_builddir}/%{name}-%{version}/README %{buildroot}%{_docdir}/%{name}/README
echo "No tests performed." > %{_builddir}/%{name}-%{version}/stestlib.log
cp %{_builddir}/%{name}-%{version}/stestlib.log %{buildroot}%{_docdir}/%{name}/stestlib.log
cp %{SOURCE3} %{buildroot}%{_docdir}/%{name}

# install javadoc
mkdir -p %{buildroot}%{_javadocdir}/%{name}
rm -rf %{_builddir}/%{name}-%{version}/bindings/javadoc/META-INF
cp -r %{_builddir}/%{name}-%{version}/bindings/javadoc/* %{buildroot}%{_javadocdir}/%{name}

# install python3 module
mkdir -p %{buildroot}%{python3_sitelib}
cp %{_builddir}/%{name}-%{version}/bindings/build/lib.linux-*/cryptlib_py.cpython-3*-x86_64-linux-gnu.so %{buildroot}%{python3_sitelib}/cryptlib_py.so

# used to filter out a reqirement of a specific perlib used to compile
%global __requires_exclude_from /usr/lib64/perl5/auto/PerlCryptLib/PerlCryptLib\.so
# install Perl module
mkdir -p %{buildroot}/usr/local/lib64
mkdir -p %{buildroot}%{_libdir}/perl5
mkdir -p %{buildroot}%{_mandir}/man3
cd %{_builddir}/%{name}-%{version}/bindings
mkdir -p %{_builddir}/include

cp ../cryptlib.h %{_builddir}/include
cp ../tools/GenPerl.pl .
export PERL_CRYPT_LIB_HEADER=%{_builddir}/include/cryptlib.h
/usr/bin/perl Makefile.PL INSTALLDIRS=vendor
sed -i '/LDLOADLIBS = /s/thread/thread -L.. -lcl/' Makefile
make
make pure_install DESTDIR=%{buildroot}
# clean the install
find %{buildroot} -type f -name .packlist -delete
find %{buildroot} -type f -name 'PerlCryptLib.so' -exec chmod 0755 {} \;

# install test programs
cp %{_builddir}/%{name}-%{version}/stestlib %{buildroot}%{cryptlibdir}
cp -r %{_builddir}/%{name}-%{version}/test %{buildroot}%{cryptlibdir}/test

cd %{buildroot}%{cryptlibdir}
tar xpzf %{SOURCE5} 

%check
# checks are performed after install
# in KOJI tests must be disabled as there is no networking
%if %{includetests}
     cd %{_builddir}/%{name}-%{version}
     ln -s libcl.so.3.4.7 ./libcl.so.3
     export LD_LIBRARY_PATH=.
     echo "Running tests on the cryptlib library. This will take a few minutes."
     echo "Network access is necessary to complete all tests!"
     ./stestlib | tee   %{_builddir}/%{name}-%{version}/stestlib.log
     cp %{_builddir}/%{name}-%{version}/stestlib.log %{buildroot}%{_docdir}/%{name}/stestlib.log
%endif

# install cryptlib tools
mkdir -p %{buildroot}%{cryptlibdir}/tools
cd %{buildroot}%{cryptlibdir}/tools
tar xpzf %{SOURCE6}
mkdir -p %{buildroot}%{_mandir}/man1
mkdir -p %{buildroot}%{_bindir}
cp /%{buildroot}%{cryptlibdir}/tools/clsha1 %{buildroot}%{_bindir}
cp /%{buildroot}%{cryptlibdir}/tools/clsha2 %{buildroot}%{_bindir}
cp /%{buildroot}%{cryptlibdir}/tools/claes %{buildroot}%{_bindir}
cp /%{buildroot}%{cryptlibdir}/tools/clkeys %{buildroot}%{_bindir}
cp /%{buildroot}%{cryptlibdir}/tools/clsmime %{buildroot}%{_bindir}
cp /%{buildroot}%{cryptlibdir}/tools/man/clsha1.1 %{buildroot}%{_mandir}/man1
cp /%{buildroot}%{cryptlibdir}/tools/man/clsha2.1 %{buildroot}%{_mandir}/man1
cp /%{buildroot}%{cryptlibdir}/tools/man/claes.1 %{buildroot}%{_mandir}/man1
cp /%{buildroot}%{cryptlibdir}/tools/man/clkeys.1 %{buildroot}%{_mandir}/man1
cp /%{buildroot}%{cryptlibdir}/tools/man/clsmime.1 %{buildroot}%{_mandir}/man1

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig


%files
%{_libdir}/libcl.so.3.4.8
%{_libdir}/libcl.so.3.4
%{_libdir}/libcl.so.3

%license   %{_datadir}/licenses/%{name}/COPYING
%doc       %{_docdir}/%{name}/README
%doc       %{_docdir}/%{name}/manual.pdf
%doc       %{_docdir}/%{name}/stestlib.log


# files devel
%{_libdir}/libcl.so
%{_includedir}/%{name}/crypt.h
%{_includedir}/%{name}/cryptkrn.h
%{_includedir}/%{name}/cryptlib.h

# files java
%{_jnidir}/cryptlib.jar

# files javadoc
%{_javadocdir}/%{name}

# files python3
%{python3_sitelib}/cryptlib_py.so

# files perl
%{_libdir}/perl5
%{_mandir}/man3/PerlCryptLib.3pm.gz

# files test
%{cryptlibdir}

# files tools
%{_bindir}/clsha1
%{_bindir}/clsha2
%{_bindir}/claes
%{_bindir}/clkeys
%{_bindir}/clsmime
%{_mandir}/man1/clsha1.1
%{_mandir}/man1/clsha2.1
%{_mandir}/man1/claes.1
%{_mandir}/man1/clkeys.1
%{_mandir}/man1/clsmime.1

%changelog
* Sun Jun 15 2025 Senderek Web Security <innovation@senderek.ie> - 3.4.8-2
- update cryptlib-tools, manuals and tests

* Sun Mar 30 2025 Senderek Web Security <innovation@senderek.ie> - 3.4.8-1
- update to version 3.4.8

* Tue Nov 07 2023 Senderek Web Security <innovation@senderek.ie> - 3.4.7-1
- update to version 3.4.7

* Mon Jun 05 2023 Senderek Web Security <innovation@senderek.ie> - 3.4.6-2
- force x86-64-v3

* Mon Jun 06 2022 Senderek Web Security <innovation@senderek.ie> - 3.4.6-1
- update to version 3.4.6 (beta)

* Tue Jun 11 2019 Senderek Web Security <innovation@senderek.ie> - 3.4.5-1
- update to version 3.4.5

* Tue Nov 22 2016 Senderek Web Security <innovation@senderek.ie> - 3.4.3-1
- initial build of the all-inclusive RPM
